# Stow

Documentation can be found in [docs/index.md](docs/index.md)

Change log can be found here [docs/changelog.md](docs/changelog.md)

## Running tests with coverage

```
pytest --cov-config=.coveragerc --cov=stow --cov-report html tests/
```